Jenkins
=======

The Jenkins source pulls data from the Jenkins API.

Usage
^^^^^

To following is a configuration sample of how to configure the Jenkins source

.. include:: ../config_samples/minimal_configuration.rst

Plugin Support
^^^^^^^^^^^^^^

The Jenkins source is supported by the following built-in plugins:

  * OpenStack
